@@ -3,19 +3,22 @@ import pytest
 
 ucp = pytest.importorskip("ucp")
 
-from distributed import Client
+from distributed import Client, Worker, Scheduler, wait
 from distributed.comm import ucx, listen, connect
 from distributed.comm.registry import backends, get_backend
 from distributed.comm import ucx, parse_address
 from distributed.protocol import to_serialize
 from distributed.deploy.local import LocalCluster
 from dask.dataframe.utils import assert_eq
-from distributed.utils_test import gen_test, loop, inc  # noqa: 401
+from distributed.utils_test import gen_test, loop, inc, cleanup  # noqa: 401
 
 from .test_comms import check_deserialize
 
 
-HOST = ucp.get_address()
+try:
+    HOST = ucp.get_address()
+except Exception:
+    HOST = "127.0.0.1"
 
 
 def test_registered():
@@ -33,12 +36,12 @@ async def get_comm_pair(
         await q.put(comm)
 
     listener = listen(listen_addr, handle_comm, connection_args=listen_args, **kwargs)
-    with listener:
+    async with listener:
         comm = await connect(
             listener.contact_address, connection_args=connect_args, **kwargs
         )
-        serv_com = await q.get()
-        return comm, serv_com
+        serv_comm = await q.get()
+        return (comm, serv_comm)
 
 
 @pytest.mark.asyncio
@@ -94,7 +97,7 @@ def test_ucx_specific():
             assert comm.closed
 
         listener = ucx.UCXListener(address, handle_comm)
-        listener.start()
+        await listener.start()
         host, port = listener.get_host_port()
         assert host.count(".") == 3
         assert port > 0
@@ -167,11 +170,23 @@ def test_ucx_deserialize():
         lambda cudf: cudf.DataFrame([1]).head(0),
         lambda cudf: cudf.DataFrame([1.0]).head(0),
         lambda cudf: cudf.DataFrame({"a": []}),
-        lambda cudf: cudf.DataFrame({"a": ["a"]}).head(0),
-        lambda cudf: cudf.DataFrame({"a": [1.0]}).head(0),
-        lambda cudf: cudf.DataFrame({"a": [1]}).head(0),
+        pytest.param(
+            lambda cudf: cudf.DataFrame({"a": ["a"]}).head(0),
+            marks=pytest.mark.xfail(reason="0 length objects don't deseralize cleanly"),
+        ),
+        pytest.param(
+            lambda cudf: cudf.DataFrame({"a": [1.0]}).head(0),
+            marks=pytest.mark.xfail(reason="0 length objects don't deseralize cleanly"),
+        ),
+        pytest.param(
+            lambda cudf: cudf.DataFrame({"a": [1]}).head(0),
+            marks=pytest.mark.xfail(reason="0 length objects don't deseralize cleanly"),
+        ),
         lambda cudf: cudf.DataFrame({"a": [1, 2, None], "b": [1.0, 2.0, None]}),
-        lambda cudf: cudf.DataFrame({"a": ["Check", "str"], "b": ["Sup", "port"]}),
+        pytest.param(
+            lambda cudf: cudf.DataFrame({"a": ["Check", "str"], "b": ["Sup", "port"]}),
+            marks=pytest.mark.xfail(reason="0 length objects don't deseralize cleanly"),
+        ),
     ],
 )
 async def test_ping_pong_cudf(g):
@@ -225,7 +240,7 @@ async def test_ping_pong_cupy(shape):
         ),
     ],
 )
-async def test_large_cupy(n):
+async def test_large_cupy(n, cleanup):
     cupy = pytest.importorskip("cupy")
     com, serv_com = await get_comm_pair()
 
@@ -242,7 +257,7 @@ async def test_large_cupy(n):
 
 
 @pytest.mark.asyncio
-async def test_ping_pong_numba():
+async def test_ping_pong_numba(cleanup):
     np = pytest.importorskip("numpy")
     numba = pytest.importorskip("numba")
     import numba.cuda
@@ -260,21 +275,20 @@ async def test_ping_pong_numba():
 
 
 @pytest.mark.parametrize("processes", [True, False])
-def test_ucx_localcluster(loop, processes):
-    if processes:
-        pytest.skip("Known bug, processes=True doesn't work currently")
-
-    with LocalCluster(
-        protocol="ucx",
+@pytest.mark.asyncio
+async def test_ucx_localcluster(processes, cleanup):
+    async with LocalCluster(
+        protocol="ucx:://",
+        host=HOST,
         dashboard_address=None,
         n_workers=2,
         threads_per_worker=1,
         processes=processes,
-        loop=loop,
+        asynchronous=True,
     ) as cluster:
-        with Client(cluster) as client:
+        async with Client(cluster, asynchronous=True) as client:
             x = client.submit(inc, 1)
-            x.result()
+            await x.result()
             assert x.key in cluster.scheduler.tasks
             if not processes:
                 assert any(w.data == {x.key: 2} for w in cluster.workers.values())
@@ -283,14 +297,17 @@ def test_ucx_localcluster(loop, processes):
 
 @pytest.mark.slow
 @pytest.mark.asyncio
-async def test_stress():
-    import dask.array as da
-    from distributed import wait
+async def test_stress(cleanup):
+    da = pytest.importorskip("dask.array")
 
     chunksize = "10 MB"
 
     async with LocalCluster(
-        protocol="ucx", dashboard_address=None, asynchronous=True, processes=False
+        protocol="ucx",
+        dashboard_address=None,
+        asynchronous=True,
+        processes=False,
+        host=HOST,
     ) as cluster:
         async with Client(cluster, asynchronous=True) as client:
             rs = da.random.RandomState()
@@ -303,3 +320,33 @@ async def test_stress():
                 x = x.rechunk((-1, chunksize))
                 x = x.persist()
                 await wait(x)
+
+
+@pytest.mark.asyncio
+async def test_simple(cleanup):
+    async with Scheduler(protocol="ucx") as s:
+        async with Worker(s.address) as a:
+            async with Client(s.address, asynchronous=True) as c:
+                result = await c.submit(lambda x: x + 1, 10)
+                assert result == 11
+
+
+@pytest.mark.asyncio
+async def test_transpose(cleanup):
+    da = pytest.importorskip("dask.array")
+
+    async with Scheduler(protocol="ucx") as s:
+        async with Worker(s.address) as a, Worker(s.address) as b:
+            async with Client(s.address, asynchronous=True) as c:
+                x = da.ones((10000, 10000), chunks=(1000, 1000)).persist()
+                await x
+
+                y = (x + x.T).sum()
+                await y
+
+
+@pytest.mark.asyncio
+@pytest.mark.parametrize("port", [0, 1234])
+async def test_ucx_protocol(cleanup, port):
+    async with Scheduler(protocol="ucx", port=port) as s:
+        assert s.address.startswith("ucx://")
