@@ -7,6 +7,10 @@ import sklearn.linear_model
 from distributed.protocol import serialize, deserialize
 
 
+@pytest.mark.xfail(
+    reason="We no longer special-case the BaseEstimator "
+    "super class. It's hard to guarantee support for all subclasseses"
+)
 def test_basic():
     est = sklearn.linear_model.LinearRegression()
     est.fit([[0, 0], [1, 1], [2, 2]], [0, 1, 2])
