@@ -3,7 +3,7 @@ from collections.abc import MutableMapping
 from .utils import log_errors, tokey
 
 
-class PublishExtension(object):
+class PublishExtension:
     """ An extension for the scheduler to manage collections
 
     *  publish-list
