@@ -1774,6 +1774,8 @@ async def test_task_groups(c, s, a, b):
 
     await c.replicate(y)
     assert tg.nbytes_in_memory == y.nbytes
+    assert "array" in str(tg.types)
+    assert "array" in str(tp.types)
 
     del y
 
@@ -1782,8 +1784,9 @@ async def test_task_groups(c, s, a, b):
 
     assert tg.nbytes_in_memory == 0
     assert tg.states["forgotten"] == 5
-    assert "array" in str(tg.types)
-    assert "array" in str(tp.types)
+    # Ensure TaskGroup is removed once all tasks are in forgotten state
+    assert tg.name not in s.task_groups
+    assert sys.getrefcount(tg) == 2
 
 
 @gen_cluster(client=True)
@@ -1795,6 +1798,44 @@ async def test_task_prefix(c, s, a, b):
 
     assert s.task_prefixes["sum-aggregate"].states["memory"] == 1
 
+    a = da.arange(101, chunks=(20,))
+    b = (a + 1).sum().persist()
+    b = await b
+
+    assert s.task_prefixes["sum-aggregate"].states["memory"] == 2
+
+
+@gen_cluster(client=True)
+async def test_task_group_non_tuple_key(c, s, a, b):
+    da = pytest.importorskip("dask.array")
+    np = pytest.importorskip("numpy")
+    x = da.arange(100, chunks=(20,))
+    y = (x + 1).sum().persist()
+    y = await y
+
+    assert s.task_prefixes["sum"].states["released"] == 4
+    assert "sum" not in s.task_groups
+
+    f = c.submit(np.sum, [1, 2, 3])
+    await f
+
+    assert s.task_prefixes["sum"].states["released"] == 4
+    assert s.task_prefixes["sum"].states["memory"] == 1
+    assert "sum" in s.task_groups
+
+
+@gen_cluster(client=True)
+async def test_task_unique_groups(c, s, a, b):
+    """ This test ensure that task groups remain unique when using submit
+    """
+    x = c.submit(sum, [1, 2])
+    y = c.submit(len, [1, 2])
+    z = c.submit(sum, [3, 4])
+    await asyncio.wait([x, y, z])
+
+    assert s.task_prefixes["len"].states["memory"] == 1
+    assert s.task_prefixes["sum"].states["memory"] == 2
+
 
 class BrokenComm(Comm):
     peer_address = None
